---
name: Feature Issue
about: For new ideas, developments and features
title: Your title should make sense if said after "The issue is <your issue title>"
labels: "enhancement"
assignees: ''

---

## Description of the issue

Describe the problem in as much detail as possible. 

## Ideas of solution

Describe possible ideas for solution and evaluate advantages and disadvantages.

## Workflow checklist
- [ ] I am aware of the workflow in [CONTRIBUTING.md](https://github.com/OpenEnergyPlatform/open-MaStR/blob/production/CONTRIBUTING.md)
